pub struct BatchRekeyReply {
pub dry_run: bool,
pub requested_node_ids: i32,
pub resolved_node_ids: i32,
pub missing_node_ids: Vec<String>,
pub scopes: Vec<ScopeRekeyResult>,
pub temporal_nodes_updated: i32,
pub calibrations_updated: i32,
pub updated_scopes: i32,
pub conflict_scopes: i32,
}Fields
dry_run: boolrequested_node_ids: i32resolved_node_ids: i32missing_node_ids: Vec<String>scopes: Vec<ScopeRekeyResult>temporal_nodes_updated: i32calibrations_updated: i32updated_scopes: i32conflict_scopes: i32Trait Implementations
Sourceimpl Clone for BatchRekeyReply
impl Clone for BatchRekeyReply
Sourcefn clone(&self) -> BatchRekeyReply
fn clone(&self) -> BatchRekeyReply
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BatchRekeyReply
impl Debug for BatchRekeyReply
Sourceimpl Default for BatchRekeyReply
impl Default for BatchRekeyReply
Sourceimpl Message for BatchRekeyReply
impl Message for BatchRekeyReply
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BatchRekeyReply
impl PartialEq for BatchRekeyReply
impl StructuralPartialEq for BatchRekeyReply